@@ -4,6 +4,6 @@ mod parser;
 mod utils;
 
 use anyhow::Error;
-pub use cli::{run, Runner};
+pub use cli::Cli;
 
 pub type Result<T> = std::result::Result<T, Error>;
