@@ -1,7 +1,7 @@
 use anyhow::{anyhow, bail, Result};
-use clap::{arg, ArgAction, Command};
+use clap::{Arg, ArgAction, Command};
 use std::{
-    env, fs, io,
+    env, fs,
     path::{Path, PathBuf},
     process,
 };
@@ -24,9 +24,11 @@ fn main() {
 fn run() -> Result<i32> {
     let mut args: Vec<String> = vec![];
     let mut script_args: Vec<String> = vec![];
-    for (i, arg) in std::env::args().enumerate() {
-        if i == 0 {
+    let mut is_arg = true;
+    for arg in std::env::args() {
+        if is_arg {
             args.push(arg);
+            is_arg = false;
             continue;
         }
         if script_args.is_empty() && arg.starts_with("--argc-") {
@@ -34,10 +36,25 @@ fn run() -> Result<i32> {
             continue;
         }
         script_args.push(arg);
+        is_arg = false;
     }
     let matches = Command::new(env!("CARGO_CRATE_NAME"))
         .version(env!("CARGO_PKG_VERSION"))
         .author(env!("CARGO_PKG_AUTHORS"))
+        .global_setting(clap::AppSettings::DeriveDisplayOrder)
+        .override_usage(
+            r#"
+    argc --argc-eval SCRIPT [ARGS ...]             Print code snippets for `eval $(argc --argc-eval "$0" "$@")`
+    argc --argc-compgen SCRIPT [ARGS ...]          Print commands and options as completion candidates 
+    argc --argc-argcfile                           Print argcfile path
+    argc --argc-help                               Print help information
+    argc --argc-version                            Print version information"#,
+        )
+        .help_template(r#"{bin} {version}
+{author}
+{about}
+
+USAGE:{usage}"#)
         .disable_help_flag(true)
         .disable_version_flag(true)
         .disable_help_subcommand(true)
@@ -46,20 +63,27 @@ fn run() -> Result<i32> {
             " - ",
             env!("CARGO_PKG_REPOSITORY")
         ))
-        .arg(arg!(--"argc-eval" "Print code snippets for eval"))
-        .arg(arg!(--"argc-completion" "Print bash completion script"))
-        .arg(arg!(--"argc-version" "Print version information").action(ArgAction::Version))
-        .arg(arg!(--"argc-help" "Print help information").action(ArgAction::Help))
-        .arg(arg!([SCRIPT] "Specific script file"))
-        .arg(arg!([ARGUMENTS]... "Arguments passed to script file"))
+        .arg(Arg::new("argc-eval").long("argc-eval"))
+        .arg(
+            Arg::new("argc-compgen")
+                .long("argc-compgen"))
+        .arg(
+            Arg::new("argc-argcfile")
+                .long("argc-argcfile")
+        )
+        .arg(
+            Arg::new("argc-version")
+                .long("argc-version")
+                .action(ArgAction::Version)
+        )
+        .arg(
+            Arg::new("argc-help")
+                .long("argc-help")
+                .action(ArgAction::Help)
+        )
         .try_get_matches_from(&args)?;
 
-    if matches.is_present("argc-completion") {
-        let (source, cmd_args) = parse_script_args(&script_args)?;
-        let cli = argc::Cli::new(&source);
-        let cmd_args: Vec<&str> = cmd_args.iter().map(|v| v.as_str()).collect();
-        cli.complete(cmd_args[0], &mut io::stdout())?;
-    } else if matches.is_present("argc-eval") {
+    if matches.is_present("argc-eval") {
         let (source, cmd_args) = parse_script_args(&script_args)?;
         let cli = argc::Cli::new(&source);
         let cmd_args: Vec<&str> = cmd_args.iter().map(|v| v.as_str()).collect();
@@ -72,10 +96,15 @@ fn run() -> Result<i32> {
                 println!("exit 1");
             }
         }
+    } else if matches.is_present("argc-argcfile") {
+        let (_, script_file) = get_script_path().ok_or_else(|| anyhow!("Not found script file"))?;
+        print!("{}", script_file.display());
+    } else if matches.is_present("argc-compgen") {
+        let (source, cmd_args) = parse_script_args(&script_args)?;
+        let cli = argc::Cli::new(&source);
+        let cmd_args: Vec<&str> = cmd_args.iter().map(|v| v.as_str()).collect();
+        print!("{}", cli.compgen(&cmd_args)?.join(" "))
     } else {
-        if env::var("ARGC_MODE").is_ok() {
-            bail!("Recognized an infinite loop, did you forget to add the `--argc-eval` option in eval");
-        }
         let shell = get_shell_path().ok_or_else(|| anyhow!("Not found shell"))?;
         let (script_dir, script_file) =
             get_script_path().ok_or_else(|| anyhow!("Not found script file"))?;
@@ -83,7 +112,6 @@ fn run() -> Result<i32> {
         command.arg(&script_file);
         command.args(&script_args);
         command.current_dir(script_dir);
-        command.env("ARGC_MODE", "true");
         let status = command
             .status()
             .map_err(|err| anyhow!("Run `{}` throw {}", script_file.display(), err))?;
@@ -101,7 +129,7 @@ fn parse_script_args(args: &[String]) -> Result<(String, Vec<String>)> {
     let source = fs::read_to_string(script_file)
         .map_err(|e| anyhow!("Failed to load '{}', {}", script_file, e))?;
     let name = Path::new(script_file)
-        .file_stem()
+        .file_name()
         .and_then(|v| v.to_str())
         .ok_or_else(|| anyhow!("Failed to get script name"))?;
     let mut cmd_args = vec![name.to_string()];
