@@ -1,5 +1,4 @@
 use assert_cmd::prelude::*;
-use std::path::Path;
 use std::process::Command;
 
 #[test]
@@ -24,14 +23,3 @@ fn help() {
         .stderr(predicates::str::contains(env!("CARGO_PKG_DESCRIPTION")))
         .failure();
 }
-
-#[test]
-fn completion() {
-    Command::cargo_bin("argc")
-        .unwrap()
-        .arg("--argc-completion")
-        .arg(Path::new("tests").join("spec.sh"))
-        .assert()
-        .stdout(predicates::str::contains("_spec() {"))
-        .success();
-}
