@@ -63,15 +63,30 @@ macro_rules! fatal {
 }
 
 #[macro_export]
-macro_rules! complete {
+macro_rules! snapshot_compgen {
     (
         $source:expr,
-        $name:expr
+        $args:expr
     ) => {
         let cli = argc::Cli::new($source);
-        let mut bufs: Vec<u8> = vec![];
-        cli.complete($name, &mut bufs).unwrap();
-        let output = std::str::from_utf8(&bufs).unwrap();
+        let (stdout, stderr) = match cli.compgen($args) {
+            Ok(stdout) => (stdout.join(" "), String::new()),
+            Err(stderr) => (String::new(), stderr.to_string()),
+        };
+
+        let args = $args.join(" ");
+        let output = format!(
+            r###"RUN
+{}
+
+STDOUT
+{}
+
+STDERR
+{}
+"###,
+            args, stdout, stderr
+        );
         insta::assert_snapshot!(output);
     };
 }
