@@ -1,10 +1,12 @@
+const SPEC_SCRIPT: &str = include_str!("spec.sh");
+
 mod fixtures;
 
 #[macro_use]
 mod macros;
 mod argcfile;
 mod cli;
-mod complete_test;
+mod compgen;
 mod escape_test;
 mod fail_test;
 mod help_tag_test;
